@@ -45,6 +45,7 @@ tag_box_header = 0b0100000000001111
 btag_bignum = 0x01000000
 btag_ratnum = 0x02000000
 btag_symbol = 0x03000000
+btag_port = 0x04000000
 
 mask_char  = 0xff
 mask_flonum = 0xff
@@ -63,6 +64,7 @@ shift_fixnum = 3
 shift_char = 8
 shift_boolean = 8
 shift_singular = 8
+shift_void = 16
 
 value_false = tag_boolean
 
@@ -92,6 +94,11 @@ class LokoCharPrinter(LokoPrinter):
         return "#\\%c" % (self.val >> shift_char)
 
 
+class LokoVoidPrinter(LokoPrinter):
+    def to_string(self):
+        return "#<void #x%x>" % (self.val >> shift_void)
+
+
 class LokoPairPrinter(LokoPrinter):
     def to_string(self):
         car = deref(self.val, 0)
@@ -172,6 +179,14 @@ class LokoSymbolPrinter(LokoBoxPrinter):
         return namebv.decode('utf-8')
 
 
+class LokoPortPrinter(LokoBoxPrinter):
+    def to_string(self):
+        return '#<port>'
+
+    def display_hint(self):
+        return 'port'
+
+
 class LokoRecordPrinter(LokoBoxPrinter):
     def __init__(self, val, boxheader):
         super(LokoRecordPrinter, self).__init__(val, boxheader)
@@ -305,6 +320,8 @@ def loko_lookup_function(val):
                         return LokoGensymPrinter(val, boxheader)
                     else:
                         return LokoSymbolPrinter(val, boxheader)
+                elif int(boxheader) & mask_boxhdr_type == btag_port:
+                    return LokoPortPrinter(val, boxheader)
 
             return LokoBoxPrinter(val, boxheader)
 
@@ -330,6 +347,10 @@ def loko_lookup_function(val):
         if tag8 == tag_char:
             return LokoCharPrinter(val)
 
+        tag16 = int(val) & 0xffff
+        if tag16 == tag_void:
+            return LokoVoidPrinter(val)
+
         return LokoPrinter(val)
 
     return None
